
;+
;PROCEDURE:	load_sta_l1_sweadist
;PURPOSE:	
;   loads STEREO/IMPACT SWEA 3D high resolution data for "tplot".
;
;INPUTS:	none, but will call "timespan" if time
;		range is not already set.
;KEYWORDS:
;  TIME_RANGE:  2 element vector specifying the time range
;  DATA:        Data returned in this named variable.
;  NODATA:	Returns 0 if data exists for time range, otherwise returns 1.
;  PREFIX:	(string) prefix for tplot variables.  Default is 'sta_'
;  NAME:	(string) name for tplot variables. Default is 'sta_let'
;  MASTERFILE:	(string) full filename of master file.
;SEE ALSO: 
;  "make_cdf_index","loadcdf","loadcdfstr","loadallcdf"
;
;CREATED BY:	Peter Schroeder
;LAST MODIFIED:	11/27/06
;-


pro load_sta_l1_sweadist,time_range=trange,data=d,  $
  nodata=nodat, $
  prefix = prefix, $
  name = bname, $
  masterfile=masterfile, novardata=nvd, res=res, onlyspec=onlyspec
  
if not keyword_set(masterfile) then masterfile = 'STA_L1U'
;cdfnames = ['B_HGRTN']
ppx = 'B'
myformat = '/disks/stereodata/l1/ahead/swea/????/??/STA_L1_SWEA_DIST_*V02.cdf'
d=0
nodat = 0

;if not keyword_set(onlyspec) then $
;   loadallcdf,myformat,time_range=trange, novarnames=novarnames, $
;    cdfnames=cdfnames,data=d,res =res, tplot_name='sta_swea_dist' $
;else loadallcdf,myformat,time_range=trange, novarnames=novarnames, $
;    cdfnames=cdfnames,data=d,res =res

;str_element,d,'ENERGY',foo,success=engsuc

;if not engsuc then begin
   d = 0
   print,'This is a SWEA V02 file'
   novarznames = 'Energy'
   if not keyword_set(onlyspec) then begin
      loadallcdf,myformat,time_range=trange, novarznames=novarznames, $
         cdfnames=cdfnames,data=d,res =res, tplot_name='sta_swea_dist', $
         novardata = novardata
      dist_cnts = d.distribution
      swea_cnts_to_flux,'sta',factor
      num_times = n_elements(dist_cnts[0,0,*])
      dist_cnts = transpose(dist_cnts,[2,1,0])
      factor_array = fltarr(num_times,16,80)
      for t = 0,num_times-1 do $
         for e = 0, 15 do $
            factor_array[t,e,*] = factor / novardata.energy[e]
      dist_flux = dist_cnts * factor_array
      store_data,'sta_swea_flux',data={x:d.time, y:dist_flux}
      store_data,'sta_swea_gfdt',data={x:d.time, y:factor_array}
;      store_data,'sta_swea_ensp',data={x:d.time, y: total(dist_flux,3), $
;         v: novardata.energy}
   endif else $
   loadallcdf,myformat,time_range=trange, novarznames=novarznames, $
         cdfnames=cdfnames,data=d,res =res, novardata = novardata
   store_data,'sweaspec',data={x: d.time, y: transpose(total(d.distribution,1)), $
      v: novardata.energy}
;endif else begin
;   store_data,'sweaspec',data={x: d.time, y: transpose(total(d.distribution,1)), $
;      v: d.energy[*,0]}
;endelse

if keyword_set(d) eq 0 then begin
   message,'No STA SWEA 3D data during this time.',/info
   nodat = 1
  return
endif


end

