
;+
;PROCEDURE:	load_stb_l1_steb
;PURPOSE:	
;   loads STEREOB/IMPACT STE high resolution burst data for "tplot".
;
;INPUTS:	none, but will call "timespan" if time
;		range is not already set.
;KEYWORDS:
;  TIME_RANGE:  2 element vector specifying the time range
;  DATA:        Data returned in this named variable.
;  NODATA:	Returns 0 if data exists for time range, otherwise returns 1.
;  PREFIX:	(string) prefix for tplot variables.  Default is 'stb_steb_'
;SEE ALSO: 
;  "make_cdf_index","loadcdf","loadcdfstr","loadallcdf"
;
;CREATED BY:	Peter Schroeder
;LAST MODIFIED:	11/27/06
;-


pro load_stb_l1_steb,time_range=trange,data=d,  $
  nodata=nodat, $
  prefix = prefix
  
if not keyword_set(masterfile) then masterfile = 'STB_L1U'
cdfnames = ['STE_spectra', 'STE_energy']
ppx = 'stb'
myformat = getenv('STB_L1U')+'/STB_L1_STEB_*.cdf'

d=0
nodat = 0

loadallcdf,myformat,time_range=trange, $
    cdfnames=cdfnames,data=d,res =res

if keyword_set(d) eq 0 then begin
   message,'No STB STEB data during this time.',/info
   nodat = 1
  return
endif


if data_type(prefix) eq 7 then px=prefix else px = 'stb_steb'

time  = reform(d.time)
str_element,d,cdfnames(0),STE_spectra
STE_spectra_U0 = reform(STE_spectra[0,*,*])
STE_spectra_U0 = transpose(STE_spectra_U0)
STE_spectra_U1 = reform(STE_spectra[1,*,*])
STE_spectra_U1 = transpose(STE_spectra_U1)
STE_spectra_U2 = reform(STE_spectra[2,*,*])
STE_spectra_U2 = transpose(STE_spectra_U2)
STE_spectra_U3 = reform(STE_spectra[3,*,*])
STE_spectra_U3 = transpose(STE_spectra_U3)

STE_spectra_D0 = reform(STE_spectra[4,*,*])
STE_spectra_D0 = transpose(STE_spectra_D0)
STE_spectra_D1 = reform(STE_spectra[5,*,*])
STE_spectra_D1 = transpose(STE_spectra_D1)
STE_spectra_D2 = reform(STE_spectra[6,*,*])
STE_spectra_D2 = transpose(STE_spectra_D2)
STE_spectra_D3 = reform(STE_spectra[7,*,*])
STE_spectra_D3 = transpose(STE_spectra_D3)

str_element,d,cdfnames(1),STE_energy
STE_energy_U0 = reform(STE_energy[0,*,*])
STE_energy_U0 = transpose(STE_energy_U0)
STE_energy_U1 = reform(STE_energy[1,*,*])
STE_energy_U1 = transpose(STE_energy_U1)
STE_energy_U2 = reform(STE_energy[2,*,*])
STE_energy_U2 = transpose(STE_energy_U2)
STE_energy_U3 = reform(STE_energy[3,*,*])
STE_energy_U3 = transpose(STE_energy_U3)

STE_energy_D0 = reform(STE_energy[4,*,*])
STE_energy_D0 = transpose(STE_energy_D0)
STE_energy_D1 = reform(STE_energy[5,*,*])
STE_energy_D1 = transpose(STE_energy_D1)
STE_energy_D2 = reform(STE_energy[6,*,*])
STE_energy_D2 = transpose(STE_energy_D2)
STE_energy_D3 = reform(STE_energy[7,*,*])
STE_energy_D3 = transpose(STE_energy_D3)

store_data,px+'_U0',data={x:time,y:STE_spectra_U0,v:STE_energy_U0}
store_data,px+'_U1',data={x:time,y:STE_spectra_U1,v:STE_energy_U1}
store_data,px+'_U2',data={x:time,y:STE_spectra_U2,v:STE_energy_U2}
store_data,px+'_U3',data={x:time,y:STE_spectra_U3,v:STE_energy_U3}
store_data,px+'_D0',data={x:time,y:STE_spectra_D0,v:STE_energy_D0}
store_data,px+'_D1',data={x:time,y:STE_spectra_D1,v:STE_energy_D1}
store_data,px+'_D2',data={x:time,y:STE_spectra_D2,v:STE_energy_D2}
store_data,px+'_D3',data={x:time,y:STE_spectra_D3,v:STE_energy_D3}

end

